AadhaarValidator class
Constructors
- AadhaarValidator()
-
validate the AADHAAR number.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
String? aadhaar) → String? - AADHAAR format is 9999 9999 9999
-
isValid(
String? aadhaar) → bool -
function to check if the provider
aadhaaris valid or not. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited